@@ -1,7 +1,7 @@
 # Main running methods file
 package Lemonldap::NG::Handler::Main::Run;
 
-our $VERSION = '2.21.0';
+our $VERSION = '2.22.0';
 
 package Lemonldap::NG::Handler::Main;
 
@@ -71,7 +71,7 @@ sub checkEvent {
                 $ret = $msg->{action};
             }
             else {
-                $class->logger->error("Unkown action $msg->{action}");
+                $class->logger->debug("Unknown action $msg->{action}");
             }
         }
         else {
@@ -228,7 +228,7 @@ sub run {
         # Log access granted
         $class->logger->debug( "User "
               . $session->{ $class->tsv->{whatToTrace} }
-              . " was granted to access to $uri" );
+              . " was granted access to $uri" );
 
         #  Catch POST rules
         $class->postOutputFilter( $req, $session, $uri );
@@ -365,7 +365,7 @@ sub getLevel {
 # Grant or refuse client using compiled regexp and functions
 # @param $uri URI
 # @param $cond optional Function granting access
-# @return True if the user is granted to access to the current URL
+# @return True if the user is granted access to the current URL
 sub grant {
     my ( $class, $req, $session, $uri, $cond, $vhost ) = @_;
 
@@ -445,7 +445,7 @@ sub forbidden {
         message => (
                 "User "
               . $session->{ $class->tsv->{whatToTrace} }
-              . " was forbidden to access to $vhost$uri"
+              . " was forbidden access to $vhost$uri"
         ),
         code => "ACCESS_REFUSED",
         user => $session->{ $class->tsv->{whatToTrace} },
@@ -891,6 +891,35 @@ sub localUnlog {
     }
 }
 
+## @rmethod buildAndLoadType(string package)
+# Try to load type or build it
+my %alreadyBuilt;
+
+sub buildAndLoadType {
+    my ( $class, $package ) = @_;
+    unless ( $package =~ /^[\w:]+$/ ) {
+        $class->logger->error("Bad clas name: $package");
+        return;
+    }
+    return if $alreadyBuilt{$package};
+    eval "require $package";
+    if ($@) {
+        my $lastError = $@;
+        my $main      = $package;
+        $main =~ s/::([^:]*)$/::Main/;
+        my $type = $1 or die "Malformed package $package";
+        eval <<EOF;
+package $package;
+use base 'Lemonldap::NG::Handler::Lib::$type',
+  '$main';
+1;
+EOF
+        die "Unable to build wrapper.\n First try: $lastError\n Auto-build: $@"
+          if ($@);
+    }
+    $alreadyBuilt{$package} = 1;
+}
+
 ## @rmethod protected postOutputFilter(string uri)
 # Add a javascript to html page in order to fill html form with fake data
 # @param uri URI to catch
